Products.ZMySQLDA
=================

.. image:: https://api.travis-ci.com/zms-publishing/Products.ZMySQLDA.svg?branch=master
   :target: https://travis-ci.com/zms-publishing/Products.ZMySQLDA

.. image:: https://readthedocs.org/projects/zmysqlda/badge/?version=latest
   :target: https://zmysqlda.readthedocs.io
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/Products.ZMySQLDA.svg
   :target: https://pypi.org/project/Products.ZMySQLDA/
   :alt: Latest stable release on PyPI

.. image:: https://img.shields.io/pypi/pyversions/Products.ZMySQLDA.svg
   :target: https://pypi.org/project/Products.ZMySQLDA/
   :alt: Stable release supported Python versions

This is the MySQL database adapter product for Zope.

Compatibility
-------------
* ``Zope2`` 2.13.26 and up under Python 2.7 in conjunction with
  ``Products.ZSQLMethods`` up to and including 2.13.5.

* ``Zope`` 4 after 4.0beta5 under Python 2.7 and Python 3.5 and higher.

* MySQL versions 3.22 and later including MariaDB. You need version 4.1
  or higher for unicode support.
